@@ -369,7 +369,7 @@ def table_creator(base, connection, model_mapping):
     pg_base.drop_replication_slot(
         f'{connection.engine.url.database}_testdb'
     )
-    pg_base.create_logical_replication_slot(
+    pg_base.create_replication_slot(
         f'{connection.engine.url.database}_testdb'
     )
     yield
